# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/styles/theme-style/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/styles/theme-style/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Styles\\ThemeStyle\\": "packages/styles/theme-style/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Styles\ThemeStyle\Providers\ThemeStyleServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'ThemeStyle'  => Styles\ThemeStyle\Facades\ThemeStyle::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Styles\\ThemeStyleTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Styles\ThemeStyle\Providers\ThemeStyleServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Styles\ThemeStyle\Providers\ThemeStyleServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Styles\ThemeStyle\Providers\ThemeStyleServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/theme-style/{modulename}

**User**

    http://path-to-route-folder/user/theme-style/{modulename}

**Public**

    http://path-to-route-folder/theme-styles


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/theme-style/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/theme-style/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/theme-style/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/theme-style/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/theme-style/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/theme-style/{modulename}/{slug}
    METHOD: GET