<?php

namespace Styles\ThemeStyle\Policies;

use Litepie\User\Contracts\UserPolicy;
use Styles\ThemeStyle\Models\Styles;

class StylesPolicy
{

    /**
     * Determine if the given user can view the styles.
     *
     * @param UserPolicy $user
     * @param Styles $styles
     *
     * @return bool
     */
    public function view(UserPolicy $user, Styles $styles)
    {
        if ($user->canDo('theme-style.styles.view') && $user->isAdmin()) {
            return true;
        }

        return $styles->user_id == user_id() && $styles->user_type == user_type();
    }

    /**
     * Determine if the given user can create a styles.
     *
     * @param UserPolicy $user
     * @param Styles $styles
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('theme-style.styles.create');
    }

    /**
     * Determine if the given user can update the given styles.
     *
     * @param UserPolicy $user
     * @param Styles $styles
     *
     * @return bool
     */
    public function update(UserPolicy $user, Styles $styles)
    {
        if ($user->canDo('theme-style.styles.edit') && $user->isAdmin()) {
            return true;
        }

        return $styles->user_id == user_id() && $styles->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given styles.
     *
     * @param UserPolicy $user
     * @param Styles $styles
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Styles $styles)
    {
        return $styles->user_id == user_id() && $styles->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given styles.
     *
     * @param UserPolicy $user
     * @param Styles $styles
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Styles $styles)
    {
        if ($user->canDo('theme-style.styles.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given styles.
     *
     * @param UserPolicy $user
     * @param Styles $styles
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Styles $styles)
    {
        if ($user->canDo('theme-style.styles.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
