<?php

namespace Styles\ThemeStyle\Providers;

use Illuminate\Support\ServiceProvider;

class ThemeStyleServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'theme-style');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'theme-style');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerThemeStyle();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerThemeStyle()
    {
        $this->app->bind('theme-style', function($app) {
            return new ThemeStyle($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('ThemeStyle', 'Lavalite\ThemeStyle\Facades\ThemeStyle');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('styles.theme-style', function ($app) {
            return $this->app->make('Styles\ThemeStyle\ThemeStyle');
        });

                // Bind Styles to repository
        $this->app->bind(
            'Styles\ThemeStyle\Interfaces\StylesRepositoryInterface',
            \Styles\ThemeStyle\Repositories\Eloquent\StylesRepository::class
        );

        $this->app->register(\Styles\ThemeStyle\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Styles\ThemeStyle\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and theme-style's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'styles.theme-style'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeThemeStyle::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['styles.theme-style'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('styles/theme-style.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/theme-style')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/theme-style')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
